﻿using CallCenter.Calls;
using XF.Domain.Cache;
using XF.Domain.Dependency;

namespace CallCenter.Caches
{
    public class CallCacheManager : ICallCacheManager, IScopeDependency
    {
        private readonly ITypedCache<List<Call>> _cacheCall;
        private const string CallKey = "CallQueue";

        public CallCacheManager(ITypedCache<List<Call>> cacheCall)
        {
            _cacheCall = cacheCall;
        }

        public void AddCallCache(Call call)
        {
            var list = GetCallQueueList();
            if (list==null)
            {
                list = new List<Call>();
            }
            list.Add(call);
            _cacheCall.AddOrUpdate(CallKey, list);
        }

        public List<Call>? GetCallQueueList()
        {
            var list = _cacheCall.GetOrAdd(CallKey, k =>
            {
                return new List<Call>();
            });
            return list;
        }

        public void RemoveCallCache(string id)
        {
            var list = _cacheCall.Get(CallKey)?.ToList();
            if (list != null)
            {
                var model = list.First(x => x.Id == id);
                if (model != null)
                {
                    list.Remove(model);
                    _cacheCall.AddOrUpdate(CallKey, list);
                }
            }
        }
    }
}
